| Title: | Display Tournament Fixtures using Knock Out and Round Robin Techniques |
|---|---|
| Description: | Use of Knock Out and Round Robin Techniques in preparing tournament fixtures as discussed in the Book Health and Physical Education by 'Dr. V K Sharma'(2018,ISBN:978-93-5272-134-4). |
| Authors: | Sunil Kumar [aut], Ankit Tanwar [cre] |
| Maintainer: | Ankit Tanwar <[email protected]> |
| License: | GPL |
| Version: | 0.1.0 |
| Built: | 2026-05-27 08:38:11 UTC |
| Source: | https://github.com/cran/SportsTour |
Displays fixture for the tournament when number of teams is not exactly power of two using the "Bye" method
knock_out_fixture(number_of_teams)knock_out_fixture(number_of_teams)
number_of_teams |
input numeric |
text |
Displays fixture for the tournament along with other necessary details such as number of matches, number of rounds, number of byes etc. |
number_of_teams=4 knock_out_fixture(number_of_teams)number_of_teams=4 knock_out_fixture(number_of_teams)
Displays fixture for the tournament when number of teams is power of two
knock_out_two(number_of_teams)knock_out_two(number_of_teams)
number_of_teams |
input numeric |
text |
Displays fixture for the tournament |
number_of_teams=4 knock_out_two(number_of_teams)number_of_teams=4 knock_out_two(number_of_teams)
Displays fixture for the tournament for a given number of team using "staircase" or "cyclic" method
round_robin_fixture(number_of_teams,method)round_robin_fixture(number_of_teams,method)
number_of_teams |
numeric |
method |
method for setting fixture "staircase" for staircase method and "cyclic" for cyclic method |
text |
Displays fixture for the tournament |
number_of_teams=4 round_robin_fixture(number_of_teams,method="staircase")number_of_teams=4 round_robin_fixture(number_of_teams,method="staircase")